<?php


namespace Venom\Helper;


use Venom\Core\Config;

class TemplateUtil
{
    private static ?TemplateUtil $instance = null;
    private string $baseTemplate;
    private string $templateDir;

    private function __construct()
    {
        if (Config::getInstance()->isAdmin()) {
            $base = 'base';
            $theme = 'admin';
        } else {
            $data = Config::getInstance()->getRenderer();
            $theme = $data->theme;
            $base = $data->baseFile ?? 'base';
        }
        $this->baseTemplate = $base . '.php';
        $this->templateDir = __DIR__ . '/../../../tpl/' . $theme . '/';
    }

    public static function getInstance(): TemplateUtil
    {
        if (self::$instance === null) {
            self::$instance = new TemplateUtil();
        }
        return self::$instance;
    }

    public function getDir(): string
    {
        return $this->templateDir;
    }

    public function getBase(): string
    {
        return $this->baseTemplate;
    }

    public static function includeTemplate($template, $suffix = '.php')
    {
        $dir = self::getInstance()->getDir();
        $template .= $suffix;
        if (file_exists($dir . $template)) {
            ob_start();
            include_once $dir . $template;
            return ob_get_clean();
        }
        return '';
    }
}